@@ -9,18 +9,18 @@ from santander_sdk.api_client.exceptions import (
 )
 from santander_sdk.pix import (
     PIX_ENDPOINT,
-    TYPE_ACCOUNT_MAP,
     _check_for_rejected_exception,
     _confirm_pix_payment,
     _pix_payment_status_polling,
     _request_confirm_pix_payment,
     _request_create_pix_payment,
     _request_pix_payment_status,
-    transfer_pix_payment,
+    transfer_pix,
 )
 from mock.santander_mocker import (
-    beneficiary_dict_john_cc,
+    santander_beneciary_john,
     get_dict_payment_pix_response,
+    beneciary_john_dict_json,
 )
 from santander_sdk.types import OrderStatus, SantanderTransferResponse
 
@@ -101,27 +101,19 @@ class UnitTestPix(unittest.TestCase):
         description = "Pagamento Teste"
         tags = ["bf: 1234", "nf: 1234", "nf_data: 2021-10-10"]
         self.api_client.post.return_value = get_dict_payment_pix_response(
-            pix_id, value, OrderStatus.PENDING_VALIDATION, beneficiary_dict_john_cc
+            pix_id, value, OrderStatus.PENDING_VALIDATION, santander_beneciary_john
         )
 
         response = _request_create_pix_payment(
             self.api_client,
-            beneficiary_dict_john_cc,
+            santander_beneciary_john,
             value,
             description,
             tags=tags,
         )
         assert response == {
             "addedValue": "0.00",
-            "beneficiary": {
-                "bankCode": "123",
-                "branch": "123",
-                "documentNumber": "12345678909",
-                "documentType": "CPF",
-                "name": "John Doe",
-                "number": "1234567899",
-                "type": "checking",
-            },
+            "beneficiary": beneciary_john_dict_json,
             "debitAccount": {
                 "branch": "0001",
                 "number": "123456789",
@@ -149,20 +141,11 @@ class UnitTestPix(unittest.TestCase):
             "workspaceId": "3870ba5d-d58e-4182-992f-454e5d0e08e2",
         }
 
-        john_bank_account = beneficiary_dict_john_cc["bank_account"]
         expected_body_request = {
             "tags": tags,
             "paymentValue": str(value),
             "remittanceInformation": description,
-            "beneficiary": {
-                "branch": beneficiary_dict_john_cc["bank_account"]["agencia"],
-                "number": f"{john_bank_account['conta']}{john_bank_account['conta_dv']}",
-                "type": TYPE_ACCOUNT_MAP["checking"],
-                "documentType": "CPF",
-                "documentNumber": john_bank_account["document_number"],
-                "name": beneficiary_dict_john_cc["recebedor"]["name"],
-                "bankCode": john_bank_account["bank_code_compe"],
-            },
+            "beneficiary": beneciary_john_dict_json,
         }
         self.api_client.post.assert_called_with(
             PIX_ENDPOINT, data=expected_body_request
@@ -306,7 +289,7 @@ class UnitTestPix(unittest.TestCase):
         pix_key = "12345678909"
         value = D("100.00")
 
-        transfer_result = transfer_pix_payment(
+        transfer_result = transfer_pix(
             self.api_client,
             pix_key,
             value,
@@ -357,20 +340,20 @@ class UnitTestPix(unittest.TestCase):
         pix_key = "12345678909"
         description = "Pagamento Teste valor inválido"
 
-        transfer_result = transfer_pix_payment(
+        transfer_result = transfer_pix(
             self.api_client, pix_key, D("-21.55"), description
         )
         self.assertFalse(transfer_result["success"])
-        transfer_result = transfer_pix_payment(
+        transfer_result = transfer_pix(
             self.api_client, pix_key, D("0"), description
         )
         self.assertFalse(transfer_result["success"])
-        transfer_result = transfer_pix_payment(
+        transfer_result = transfer_pix(
             self.api_client, pix_key, D("0.00"), description
         )
         self.assertFalse(transfer_result["success"])
         self.assertIn("Valor inválido para transferência PIX", transfer_result["error"])
-        transfer_result = transfer_pix_payment(
+        transfer_result = transfer_pix(
             self.api_client, pix_key, D("21.23"), description
         )
         self.assertFalse(transfer_result["success"])
@@ -379,7 +362,7 @@ class UnitTestPix(unittest.TestCase):
         self.api_client.post.return_value = get_dict_payment_pix_response(
             "", D("100.00"), OrderStatus.PENDING_VALIDATION
         )
-        response = transfer_pix_payment(
+        response = transfer_pix(
             self.api_client, "12345678909", D("100.00"), "Pagamento Teste"
         )
         self.assertFalse(response["success"])
@@ -396,7 +379,7 @@ class UnitTestPix(unittest.TestCase):
             pix_key, value, OrderStatus.REJECTED
         )
 
-        response = transfer_pix_payment(
+        response = transfer_pix(
             self.api_client, pix_key, value, "Pagamento Teste"
         )
         self.assertFalse(response["success"])
